@@ -1,7 +1,9 @@
 """``JSONDataSet`` loads/saves data from/to a JSON file using an underlying
 filesystem (e.g.: local, S3, GCS). It uses pandas to handle the JSON file.
 """
+import logging
 from copy import deepcopy
+from io import BytesIO
 from pathlib import PurePosixPath
 from typing import Any, Dict
 
@@ -9,6 +11,7 @@ import fsspec
 import pandas as pd
 
 from kedro.io.core import (
+    PROTOCOL_DELIMITER,
     AbstractVersionedDataSet,
     DataSetError,
     Version,
@@ -16,14 +19,16 @@ from kedro.io.core import (
     get_protocol_and_path,
 )
 
+logger = logging.getLogger(__name__)
+
 
 class JSONDataSet(AbstractVersionedDataSet):
     """``JSONDataSet`` loads/saves data from/to a JSON file using an underlying
     filesystem (e.g.: local, S3, GCS). It uses pandas to handle the json file.
 
     Example adding a catalog entry with
-    `YAML API <https://kedro.readthedocs.io/en/stable/05_data/\
-        01_data_catalog.html#using-the-data-catalog-with-the-yaml-api>`_:
+    `YAML API <https://kedro.readthedocs.io/en/stable/data/\
+        data_catalog.html#using-the-data-catalog-with-the-yaml-api>`_:
 
     .. code-block:: yaml
 
@@ -91,24 +96,17 @@ class JSONDataSet(AbstractVersionedDataSet):
             credentials: Credentials required to get access to the underlying filesystem.
                 E.g. for ``GCSFileSystem`` it should look like `{'token': None}`.
             fs_args: Extra arguments to pass into underlying filesystem class constructor
-                (e.g. `{"project": "my-project"}` for ``GCSFileSystem``), as well as
-                to pass to the filesystem's `open` method through nested keys
-                `open_args_load` and `open_args_save`.
-                Here you can find all available arguments for `open`:
-                https://filesystem-spec.readthedocs.io/en/latest/api.html#fsspec.spec.AbstractFileSystem.open
-                All defaults are preserved, except `mode`, which is set to `r` when loading
-                and to `w` when saving.
+                (e.g. `{"project": "my-project"}` for ``GCSFileSystem``).
         """
         _fs_args = deepcopy(fs_args) or {}
-        _fs_open_args_load = _fs_args.pop("open_args_load", {})
-        _fs_open_args_save = _fs_args.pop("open_args_save", {})
         _credentials = deepcopy(credentials) or {}
         protocol, path = get_protocol_and_path(filepath, version)
         if protocol == "file":
             _fs_args.setdefault("auto_mkdir", True)
 
         self._protocol = protocol
-        self._fs = fsspec.filesystem(self._protocol, **_credentials, **_fs_args)
+        self._storage_options = {**_credentials, **_fs_args}
+        self._fs = fsspec.filesystem(self._protocol, **self._storage_options)
 
         super().__init__(
             filepath=PurePosixPath(path),
@@ -125,9 +123,14 @@ class JSONDataSet(AbstractVersionedDataSet):
         if save_args is not None:
             self._save_args.update(save_args)
 
-        _fs_open_args_save.setdefault("mode", "w")
-        self._fs_open_args_load = _fs_open_args_load
-        self._fs_open_args_save = _fs_open_args_save
+        if "storage_options" in self._save_args or "storage_options" in self._load_args:
+            logger.warning(
+                "Dropping `storage_options` for %s, "
+                "please specify them under `fs_args` or `credentials`.",
+                self._filepath,
+            )
+            self._save_args.pop("storage_options", None)
+            self._load_args.pop("storage_options", None)
 
     def _describe(self) -> Dict[str, Any]:
         return dict(
@@ -139,16 +142,27 @@ class JSONDataSet(AbstractVersionedDataSet):
         )
 
     def _load(self) -> Any:
-        load_path = get_filepath_str(self._get_load_path(), self._protocol)
+        load_path = str(self._get_load_path())
+        if self._protocol == "file":
+            # file:// protocol seems to misbehave on Windows
+            # (<urlopen error file not on local host>),
+            # so we don't join that back to the filepath;
+            # storage_options also don't work with local paths
+            return pd.read_json(load_path, **self._load_args)
 
-        with self._fs.open(load_path, **self._fs_open_args_load) as fs_file:
-            return pd.read_json(fs_file, **self._load_args)
+        load_path = f"{self._protocol}{PROTOCOL_DELIMITER}{load_path}"
+        return pd.read_json(
+            load_path, storage_options=self._storage_options, **self._load_args
+        )
 
     def _save(self, data: pd.DataFrame) -> None:
         save_path = get_filepath_str(self._get_save_path(), self._protocol)
 
-        with self._fs.open(save_path, **self._fs_open_args_save) as fs_file:
-            data.to_json(path_or_buf=fs_file, **self._save_args)
+        buf = BytesIO()
+        data.to_json(path_or_buf=buf, **self._save_args)
+
+        with self._fs.open(save_path, mode="wb") as fs_file:
+            fs_file.write(buf.getvalue())
 
         self._invalidate_cache()
 
