@@ -3,16 +3,14 @@
 This module implements commands available from the kedro CLI.
 """
 import importlib
-import warnings
+import sys
 import webbrowser
 from collections import defaultdict
-from copy import deepcopy
 from pathlib import Path
-from typing import Any, Sequence
+from typing import Sequence
 
 import click
 import pkg_resources
-from click.utils import get_os_args
 
 # pylint: disable=unused-import
 import kedro.config.default_logger  # noqa
@@ -32,7 +30,6 @@ from kedro.framework.cli.utils import (
     KedroCliError,
     load_entry_points,
 )
-from kedro.framework.context.context import load_context
 from kedro.framework.startup import _is_project, bootstrap_project
 
 LOGO = rf"""
@@ -51,8 +48,6 @@ def cli():  # pragma: no cover
     """Kedro is a CLI for creating and using Kedro projects. For more
     information, type ``kedro info``.
 
-    When inside a Kedro project (created with ``kedro new``) commands from
-    the project's ``cli.py`` file will also be available here.
     """
     pass
 
@@ -98,43 +93,6 @@ def docs():
     webbrowser.open(index_path)
 
 
-def get_project_context(
-    key: str = "context", project_path: Path = None, **kwargs
-) -> Any:
-    """Gets the context value from context associated with the key.
-
-    Args:
-        key: Optional key to get associated value from Kedro context.
-            Supported keys are "verbose" and "context", and it defaults to "context".
-        project_path: Optional path to where the project root is to load the context.
-            If omitted, the current working directory will be used.
-        **kwargs: Optional custom arguments defined by users, which will be passed into
-            the constructor of the projects KedroContext subclass.
-
-    Returns:
-        Requested value from Kedro context dictionary or the default if the key
-            was not found.
-
-    Raises:
-        KedroCliError: When the key is not found and the default value was not
-            specified.
-    """
-    warnings.warn(
-        "`get_project_context` is now deprecated and will be removed in Kedro 0.18.0. "
-        "Please use `KedroSession.load_context()` to access the "
-        "`KedroContext` object. For more information, please visit "
-        "https://kedro.readthedocs.io/en/stable/04_kedro_project_setup/03_session.html",
-        DeprecationWarning,
-    )
-    project_path = project_path or Path.cwd()
-    context = load_context(project_path, **kwargs)
-    # Dictionary to be compatible with existing Plugins. Future plugins should
-    # retrieve necessary Kedro project properties from context
-    value = {"context": context, "verbose": KedroCliError.VERBOSE_ERROR}[key]
-
-    return deepcopy(value)
-
-
 def _init_plugins():
     group = ENTRY_POINT_GROUPS["init"]
     for entry_point in pkg_resources.iter_entry_points(group=group):
@@ -175,8 +133,7 @@ class KedroCLI(CommandCollection):
         # This is how click's internals parse sys.argv, which include the command,
         # subcommand, arguments and options. click doesn't store this information anywhere
         # so we have to re-do it.
-        # https://github.com/pallets/click/blob/main/src/click/core.py#L942-L945
-        args = get_os_args() if args is None else list(args)
+        args = sys.argv[1:] if args is None else list(args)
         self._cli_hook_manager.hook.before_command_run(  # pylint: disable=no-member
             project_metadata=self._metadata, command_args=args
         )
@@ -199,10 +156,13 @@ class KedroCLI(CommandCollection):
 
     @property
     def project_groups(self) -> Sequence[click.MultiCommand]:
+        # pylint: disable=line-too-long
         """Property which loads all project command groups from the
         project and the plugins, then combines them with the built-in ones.
         Built-in commands can be overridden by plugins, which can be
-        overridden by the project's cli.py.
+        overridden by a custom project cli.py.
+        See https://kedro.readthedocs.io/en/stable/extend_kedro/common_use_cases.html#use-case-3-how-to-add-or-modify-cli-commands
+        on how to add this.
         """
         if not self._metadata:
             return []
