@@ -297,23 +297,6 @@ def env_option(func_=None, **kwargs):
     return opt(func_) if func_ else opt
 
 
-def ipython_message(all_kernels=True):
-    """Show a message saying how we have configured the IPython env."""
-    ipy_vars = ["startup_error", "context"]
-    click.secho("-" * 79, fg="cyan")
-    click.secho("Starting a Kedro session with the following variables in scope")
-    click.secho(", ".join(ipy_vars), fg="green")
-    line_magic = click.style("%reload_kedro", fg="green")
-    click.secho(f"Use the line magic {line_magic} to refresh them")
-    click.secho("or to see the error message if they are undefined")
-
-    if not all_kernels:
-        click.secho("The choice of kernels is limited to the default one.", fg="yellow")
-        click.secho("(restart with --all-kernels to get access to others)", fg="yellow")
-
-    click.secho("-" * 79, fg="cyan")
-
-
 @contextmanager
 def _filter_deprecation_warnings():
     """Temporarily suppress all DeprecationWarnings."""
@@ -328,7 +311,7 @@ def _check_module_importable(module_name: str) -> None:
     except ImportError as exc:
         raise KedroCliError(
             f"Module `{module_name}` not found. Make sure to install required project "
-            f"dependencies by running the `kedro install` command first."
+            f"dependencies by running the `pip install -r src/requirements.txt` command first."
         ) from exc
 
 
@@ -355,21 +338,6 @@ def load_entry_points(name: str) -> Sequence[click.MultiCommand]:
     return entry_point_commands
 
 
-def _add_src_to_path(source_dir: Path, project_path: Path) -> None:  # pragma: no cover
-    # for backwards compatibility with ipython & deployment scripts
-    # pylint: disable=import-outside-toplevel
-    from kedro.framework.startup import _add_src_to_path as real_add_src_to_path
-
-    msg = (
-        "kedro.framework.utils._add_src_to_path is deprecated. "
-        "Please import from new location kedro.framework.startup "
-        "or use `bootstrap_project()` instead for setting up "
-        "the Kedro project."
-    )
-    warnings.warn(msg, FutureWarning)
-    real_add_src_to_path(source_dir, project_path)
-
-
 def _config_file_callback(ctx, param, value):  # pylint: disable=unused-argument
     """CLI callback that replaces command line options
     with values specified in a config file. If command line
@@ -473,44 +441,5 @@ def _update_value_nested_dict(
     return nested_dict
 
 
-def _get_requirements_in(source_path: Path, create_empty: bool = False) -> Path:
-    """Get path to project level requirements.in, creating it if required.
-
-    Args:
-        source_path: Path to the project `src` folder.
-        create_empty: Whether an empty requirements.in file should be created if
-            requirements.in does not exist and there is also no requirements.txt to
-            copy requirements from.
-
-    Returns:
-        Path to requirements.in.
-
-    Raises:
-        FileNotFoundError: If neither requirements.in nor requirements.txt is found.
-
-    """
-    requirements_in = source_path / "requirements.in"
-    if requirements_in.is_file():
-        return requirements_in
-
-    requirements_txt = source_path / "requirements.txt"
-    if requirements_txt.is_file():
-        click.secho(
-            "No requirements.in found. Copying contents from requirements.txt..."
-        )
-        shutil.copyfile(str(requirements_txt), str(requirements_in))
-        return requirements_in
-
-    if create_empty:
-        click.secho("Creating empty requirements.in...")
-        requirements_in.touch()
-        return requirements_in
-
-    raise FileNotFoundError(
-        "No project requirements.in or requirements.txt found in `/src`. "
-        "Please create either and try again."
-    )
-
-
 def _get_values_as_tuple(values: Iterable[str]) -> Tuple[str, ...]:
     return tuple(chain.from_iterable(value.split(",") for value in values))
