@@ -8,10 +8,8 @@ import copy
 import difflib
 import logging
 import re
-import warnings
 from collections import defaultdict
-from functools import partial
-from typing import Any, Callable, Dict, Iterable, List, Optional, Set, Type, Union
+from typing import Any, Dict, List, Optional, Set, Type, Union
 
 from kedro.io.core import (
     AbstractDataSet,
@@ -22,9 +20,7 @@ from kedro.io.core import (
     Version,
     generate_timestamp,
 )
-from kedro.io.memory_data_set import MemoryDataSet
-from kedro.io.transformers import AbstractTransformer
-from kedro.versioning import Journal
+from kedro.io.memory_dataset import MemoryDataSet
 
 CATALOG_KEY = "catalog"
 CREDENTIALS_KEY = "credentials"
@@ -138,14 +134,10 @@ class DataCatalog:
     to the underlying data sets.
     """
 
-    # pylint: disable=too-many-arguments
     def __init__(
         self,
         data_sets: Dict[str, AbstractDataSet] = None,
         feed_dict: Dict[str, Any] = None,
-        transformers: Dict[str, List[AbstractTransformer]] = None,
-        default_transformers: List[AbstractTransformer] = None,
-        journal: Journal = None,
         layers: Dict[str, Set[str]] = None,
     ) -> None:
         """``DataCatalog`` stores instances of ``AbstractDataSet``
@@ -158,18 +150,10 @@ class DataCatalog:
         Args:
             data_sets: A dictionary of data set names and data set instances.
             feed_dict: A feed dict with data to be added in memory.
-            transformers: A dictionary of lists of transformers to be applied
-                to the data sets.
-            default_transformers: A list of transformers to be applied to any
-                new data sets.
-            journal: Instance of Journal.
             layers: A dictionary of data set layers. It maps a layer name
                 to a set of data set names, according to the
                 data engineering convention. For more details, see
-                https://kedro.readthedocs.io/en/stable/12_faq/01_faq.html#what-is-data-engineering-convention
-        Raises:
-            DataSetNotFoundError: When transformers are passed for a non
-                existent data set.
+                https://kedro.readthedocs.io/en/stable/faq/faq.html#what-is-data-engineering-convention
 
         Example:
         ::
@@ -185,18 +169,6 @@ class DataCatalog:
         self.datasets = _FrozenDatasets(self._data_sets)
         self.layers = layers
 
-        if transformers or default_transformers:
-            warnings.warn(
-                "The transformer API will be deprecated in Kedro 0.18.0."
-                "Please use Dataset Hooks to customise the load and save methods."
-                "For more information, please visit"
-                "https://kedro.readthedocs.io/en/stable/07_extend_kedro/02_hooks.html",
-                DeprecationWarning,
-            )
-        self._transformers = {k: list(v) for k, v in (transformers or {}).items()}
-        self._default_transformers = list(default_transformers or [])
-        self._check_and_normalize_transformers()
-        self._journal = journal
         # import the feed dict
         if feed_dict:
             self.add_feed_dict(feed_dict)
@@ -205,21 +177,6 @@ class DataCatalog:
     def _logger(self):
         return logging.getLogger(__name__)
 
-    def _check_and_normalize_transformers(self):
-        data_sets = self._data_sets.keys()
-        transformers = self._transformers.keys()
-        excess_transformers = transformers - data_sets
-        missing_transformers = data_sets - transformers
-
-        if excess_transformers:
-            raise DataSetNotFoundError(
-                f"Unexpected transformers for missing data_sets {', '.join(excess_transformers)}"
-            )
-
-        for data_set_name in missing_transformers:
-            self._transformers[data_set_name] = list(self._default_transformers)
-
-    # pylint: disable=too-many-arguments
     @classmethod
     def from_config(
         cls: Type,
@@ -227,7 +184,6 @@ class DataCatalog:
         credentials: Dict[str, Dict[str, Any]] = None,
         load_versions: Dict[str, str] = None,
         save_version: str = None,
-        journal: Journal = None,
     ) -> "DataCatalog":
         """Create a ``DataCatalog`` instance from configuration. This is a
         factory method used to provide developers with a way to instantiate
@@ -252,7 +208,6 @@ class DataCatalog:
                 case-insensitive string that conforms with operating system
                 filename limitations, b) always return the latest version when
                 sorted in lexicographical order.
-            journal: Instance of Journal.
 
         Returns:
             An instantiated ``DataCatalog`` containing all specified
@@ -278,7 +233,7 @@ class DataCatalog:
             >>>     "boats": {
             >>>         "type": "pandas.CSVDataSet",
             >>>         "filepath": "s3://aws-bucket-name/boats.csv",
-            >>>         "credentials": "boats_credentials"
+            >>>         "credentials": "boats_credentials",
             >>>         "save_args": {
             >>>             "index": False
             >>>         }
@@ -302,8 +257,7 @@ class DataCatalog:
         data_sets = {}
         catalog = copy.deepcopy(catalog) or {}
         credentials = copy.deepcopy(credentials) or {}
-        run_id = journal.run_id if journal else None
-        save_version = save_version or run_id or generate_timestamp()
+        save_version = save_version or generate_timestamp()
         load_versions = copy.deepcopy(load_versions) or {}
 
         missing_keys = load_versions.keys() - catalog.keys()
@@ -325,7 +279,7 @@ class DataCatalog:
             )
 
         dataset_layers = layers or None
-        return cls(data_sets=data_sets, journal=journal, layers=dataset_layers)
+        return cls(data_sets=data_sets, layers=dataset_layers)
 
     def _get_dataset(
         self, data_set_name: str, version: Version = None
@@ -350,14 +304,6 @@ class DataCatalog:
 
         return data_set
 
-    def _get_transformed_dataset_function(
-        self, data_set_name: str, operation: str, data_set: AbstractDataSet
-    ) -> Callable:
-        func = getattr(data_set, operation)
-        for transformer in reversed(self._transformers[data_set_name]):
-            func = partial(getattr(transformer, operation), data_set_name, func)
-        return func
-
     def load(self, name: str, version: str = None) -> Any:
         """Loads a registered data set.
 
@@ -393,18 +339,8 @@ class DataCatalog:
             "Loading data from `%s` (%s)...", name, type(dataset).__name__
         )
 
-        func = self._get_transformed_dataset_function(name, "load", dataset)
-        result = func()
+        result = dataset.load()
 
-        version = (
-            dataset.resolve_load_version()
-            if isinstance(dataset, AbstractVersionedDataSet)
-            else None
-        )
-
-        # Log only if versioning is enabled for the data set
-        if self._journal and version:
-            self._journal.log_catalog(name, "load", version)
         return result
 
     def save(self, name: str, data: Any) -> None:
@@ -440,18 +376,7 @@ class DataCatalog:
 
         self._logger.info("Saving data to `%s` (%s)...", name, type(dataset).__name__)
 
-        func = self._get_transformed_dataset_function(name, "save", dataset)
-        func(data)
-
-        version = (
-            dataset.resolve_save_version()
-            if isinstance(dataset, AbstractVersionedDataSet)
-            else None
-        )
-
-        # Log only if versioning is enabled for the data set
-        if self._journal and version:
-            self._journal.log_catalog(name, "save", version)
+        dataset.save(data)
 
     def exists(self, name: str) -> bool:
         """Checks whether registered data set exists by calling its `exists()`
@@ -520,7 +445,6 @@ class DataCatalog:
                     f"DataSet '{data_set_name}' has already been registered"
                 )
         self._data_sets[data_set_name] = data_set
-        self._transformers[data_set_name] = list(self._default_transformers)
         self.datasets = _FrozenDatasets(self.datasets, {data_set_name: data_set})
 
     def add_all(
@@ -591,46 +515,6 @@ class DataCatalog:
 
             self.add(data_set_name, data_set, replace)
 
-    def add_transformer(
-        self,
-        transformer: AbstractTransformer,
-        data_set_names: Union[str, Iterable[str]] = None,
-    ):
-        """Add a ``DataSet`` Transformer to the``DataCatalog``.
-        Transformers can modify the way Data Sets are loaded and saved.
-
-        Args:
-            transformer: The transformer instance to add.
-            data_set_names: The Data Sets to add the transformer to.
-                Or None to add the transformer to all Data Sets.
-        Raises:
-            DataSetNotFoundError: When a transformer is being added to a non
-                existent data set.
-            TypeError: When transformer isn't an instance of ``AbstractTransformer``
-        """
-
-        warnings.warn(
-            "The transformer API will be deprecated in Kedro 0.18.0."
-            "Please use Dataset Hooks to customise the load and save methods."
-            "For more information, please visit"
-            "https://kedro.readthedocs.io/en/stable/07_extend_kedro/02_hooks.html",
-            DeprecationWarning,
-        )
-
-        if not isinstance(transformer, AbstractTransformer):
-            raise TypeError(
-                f"Object of type {type(transformer)} is not an instance of AbstractTransformer"
-            )
-        if data_set_names is None:
-            self._default_transformers.append(transformer)
-            data_set_names = self._transformers.keys()
-        elif isinstance(data_set_names, str):
-            data_set_names = [data_set_names]
-        for data_set_name in data_set_names:
-            if data_set_name not in self._data_sets:
-                raise DataSetNotFoundError(f"No data set called {data_set_name}")
-            self._transformers[data_set_name].append(transformer)
-
     def list(self, regex_search: Optional[str] = None) -> List[str]:
         """
         List of all ``DataSet`` names registered in the catalog.
@@ -682,28 +566,10 @@ class DataCatalog:
         Returns:
             Copy of the current object.
         """
-        return DataCatalog(
-            data_sets=self._data_sets,
-            transformers=self._transformers,
-            default_transformers=self._default_transformers,
-            journal=self._journal,
-            layers=self.layers,
-        )
+        return DataCatalog(data_sets=self._data_sets, layers=self.layers)
 
     def __eq__(self, other):
-        return (
-            self._data_sets,
-            self._transformers,
-            self._default_transformers,
-            self._journal,
-            self.layers,
-        ) == (
-            other._data_sets,
-            other._transformers,
-            other._default_transformers,
-            other._journal,
-            other.layers,
-        )
+        return (self._data_sets, self.layers) == (other._data_sets, other.layers)
 
     def confirm(self, name: str) -> None:
         """Confirm a dataset by its name.
