@@ -13,7 +13,8 @@ from concurrent.futures import (
 )
 from typing import Any, Dict, Iterable
 
-from kedro.framework.hooks import get_hook_manager
+from pluggy import PluginManager
+
 from kedro.io import AbstractDataSet, DataCatalog
 from kedro.pipeline import Pipeline
 from kedro.pipeline.node import Node
@@ -39,7 +40,11 @@ class AbstractRunner(ABC):
         return logging.getLogger(self.__module__)
 
     def run(
-        self, pipeline: Pipeline, catalog: DataCatalog, run_id: str = None
+        self,
+        pipeline: Pipeline,
+        catalog: DataCatalog,
+        hook_manager: PluginManager,
+        session_id: str = None,
     ) -> Dict[str, Any]:
         """Run the ``Pipeline`` using the datasets provided by ``catalog``
         and save results back to the same objects.
@@ -47,7 +52,8 @@ class AbstractRunner(ABC):
         Args:
             pipeline: The ``Pipeline`` to run.
             catalog: The ``DataCatalog`` from which to fetch data.
-            run_id: The id of the run.
+            hook_manager: The ``PluginManager`` to activate hooks.
+            session_id: The id of the session.
 
         Raises:
             ValueError: Raised when ``Pipeline`` inputs cannot be satisfied.
@@ -76,14 +82,14 @@ class AbstractRunner(ABC):
             self._logger.info(
                 "Asynchronous mode is enabled for loading and saving data"
             )
-        self._run(pipeline, catalog, run_id)
+        self._run(pipeline, catalog, hook_manager, session_id)
 
         self._logger.info("Pipeline execution completed successfully.")
 
         return {ds_name: catalog.load(ds_name) for ds_name in free_outputs}
 
     def run_only_missing(
-        self, pipeline: Pipeline, catalog: DataCatalog
+        self, pipeline: Pipeline, catalog: DataCatalog, hook_manager: PluginManager
     ) -> Dict[str, Any]:
         """Run only the missing outputs from the ``Pipeline`` using the
         datasets provided by ``catalog``, and save results back to the
@@ -92,6 +98,7 @@ class AbstractRunner(ABC):
         Args:
             pipeline: The ``Pipeline`` to run.
             catalog: The ``DataCatalog`` from which to fetch data.
+            hook_manager: The ``PluginManager`` to activate hooks.
         Raises:
             ValueError: Raised when ``Pipeline`` inputs cannot be
                 satisfied.
@@ -116,11 +123,15 @@ class AbstractRunner(ABC):
         input_from_unregistered = to_rerun.inputs() & unregistered_ds
         to_rerun += output_to_unregistered.to_outputs(*input_from_unregistered)
 
-        return self.run(to_rerun, catalog)
+        return self.run(to_rerun, catalog, hook_manager)
 
     @abstractmethod  # pragma: no cover
     def _run(
-        self, pipeline: Pipeline, catalog: DataCatalog, run_id: str = None
+        self,
+        pipeline: Pipeline,
+        catalog: DataCatalog,
+        hook_manager: PluginManager,
+        session_id: str = None,
     ) -> None:
         """The abstract interface for running pipelines, assuming that the
         inputs have already been checked and normalized by run().
@@ -128,7 +139,8 @@ class AbstractRunner(ABC):
         Args:
             pipeline: The ``Pipeline`` to run.
             catalog: The ``DataCatalog`` from which to fetch data.
-            run_id: The id of the run.
+            hook_manager: The ``PluginManager`` to activate hooks.
+            session_id: The id of the session.
 
         """
         pass
@@ -171,25 +183,30 @@ class AbstractRunner(ABC):
 
 
 def run_node(
-    node: Node, catalog: DataCatalog, is_async: bool = False, run_id: str = None
+    node: Node,
+    catalog: DataCatalog,
+    hook_manager: PluginManager,
+    is_async: bool = False,
+    session_id: str = None,
 ) -> Node:
     """Run a single `Node` with inputs from and outputs to the `catalog`.
 
     Args:
         node: The ``Node`` to run.
         catalog: A ``DataCatalog`` containing the node's inputs and outputs.
+        hook_manager: The ``PluginManager`` to activate hooks.
         is_async: If True, the node inputs and outputs are loaded and saved
             asynchronously with threads. Defaults to False.
-        run_id: The id of the pipeline run.
+        session_id: The session id of the pipeline run.
 
     Returns:
         The node argument.
 
     """
     if is_async:
-        node = _run_node_async(node, catalog, run_id)
+        node = _run_node_async(node, catalog, hook_manager, session_id)
     else:
-        node = _run_node_sequential(node, catalog, run_id)
+        node = _run_node_sequential(node, catalog, hook_manager, session_id)
 
     for name in node.confirms:
         catalog.confirm(name)
@@ -201,16 +218,17 @@ def _collect_inputs_from_hook(
     catalog: DataCatalog,
     inputs: Dict[str, Any],
     is_async: bool,
-    run_id: str = None,
+    hook_manager: PluginManager,
+    session_id: str = None,
 ) -> Dict[str, Any]:
+    # pylint: disable=too-many-arguments
     inputs = inputs.copy()  # shallow copy to prevent in-place modification by the hook
-    hook_manager = get_hook_manager()
-    hook_response = hook_manager.hook.before_node_run(  # pylint: disable=no-member
+    hook_response = hook_manager.hook.before_node_run(
         node=node,
         catalog=catalog,
         inputs=inputs,
         is_async=is_async,
-        run_id=run_id,
+        session_id=session_id,
     )
 
     additional_inputs = {}
@@ -232,81 +250,82 @@ def _call_node_run(
     catalog: DataCatalog,
     inputs: Dict[str, Any],
     is_async: bool,
-    run_id: str = None,
+    hook_manager: PluginManager,
+    session_id: str = None,
 ) -> Dict[str, Any]:
-    hook_manager = get_hook_manager()
+    # pylint: disable=too-many-arguments
     try:
         outputs = node.run(inputs)
     except Exception as exc:
-        hook_manager.hook.on_node_error(  # pylint: disable=no-member
+        hook_manager.hook.on_node_error(
             error=exc,
             node=node,
             catalog=catalog,
             inputs=inputs,
             is_async=is_async,
-            run_id=run_id,
+            session_id=session_id,
         )
         raise exc
-    hook_manager.hook.after_node_run(  # pylint: disable=no-member
+    hook_manager.hook.after_node_run(
         node=node,
         catalog=catalog,
         inputs=inputs,
         outputs=outputs,
         is_async=is_async,
-        run_id=run_id,
+        session_id=session_id,
     )
     return outputs
 
 
-def _run_node_sequential(node: Node, catalog: DataCatalog, run_id: str = None) -> Node:
+def _run_node_sequential(
+    node: Node,
+    catalog: DataCatalog,
+    hook_manager: PluginManager,
+    session_id: str = None,
+) -> Node:
     inputs = {}
-    hook_manager = get_hook_manager()
 
     for name in node.inputs:
-        hook_manager.hook.before_dataset_loaded(  # pylint: disable=no-member
-            dataset_name=name
-        )
+        hook_manager.hook.before_dataset_loaded(dataset_name=name)
         inputs[name] = catalog.load(name)
-        hook_manager.hook.after_dataset_loaded(  # pylint: disable=no-member
-            dataset_name=name, data=inputs[name]
-        )
+        hook_manager.hook.after_dataset_loaded(dataset_name=name, data=inputs[name])
 
     is_async = False
 
     additional_inputs = _collect_inputs_from_hook(
-        node, catalog, inputs, is_async, run_id=run_id
+        node, catalog, inputs, is_async, hook_manager, session_id=session_id
     )
     inputs.update(additional_inputs)
 
-    outputs = _call_node_run(node, catalog, inputs, is_async, run_id=run_id)
+    outputs = _call_node_run(
+        node, catalog, inputs, is_async, hook_manager, session_id=session_id
+    )
 
     for name, data in outputs.items():
-        hook_manager.hook.before_dataset_saved(  # pylint: disable=no-member
-            dataset_name=name, data=data
-        )
+        hook_manager.hook.before_dataset_saved(dataset_name=name, data=data)
         catalog.save(name, data)
-        hook_manager.hook.after_dataset_saved(  # pylint: disable=no-member
-            dataset_name=name, data=data
-        )
+        hook_manager.hook.after_dataset_saved(dataset_name=name, data=data)
     return node
 
 
-def _run_node_async(node: Node, catalog: DataCatalog, run_id: str = None) -> Node:
+def _run_node_async(
+    node: Node,
+    catalog: DataCatalog,
+    hook_manager: PluginManager,
+    session_id: str = None,
+) -> Node:
     def _synchronous_dataset_load(dataset_name: str):
         """Minimal wrapper to ensure Hooks are run synchronously
         within an asynchronous dataset load."""
-        hook_manager.hook.before_dataset_loaded(  # pylint: disable=no-member
-            dataset_name=dataset_name
-        )
+        hook_manager.hook.before_dataset_loaded(dataset_name=dataset_name)
         return_ds = catalog.load(dataset_name)
-        hook_manager.hook.after_dataset_loaded(  # pylint: disable=no-member
+        hook_manager.hook.after_dataset_loaded(
             dataset_name=dataset_name, data=return_ds
         )
         return return_ds
 
     with ThreadPoolExecutor() as pool:
         inputs: Dict[str, Future] = {}
-        hook_manager = get_hook_manager()
 
         for name in node.inputs:
             inputs[name] = pool.submit(_synchronous_dataset_load, name)
@@ -315,25 +334,25 @@ def _run_node_async(node: Node, catalog: DataCatalog, run_id: str = None) -> Nod
         inputs = {key: value.result() for key, value in inputs.items()}
         is_async = True
         additional_inputs = _collect_inputs_from_hook(
-            node, catalog, inputs, is_async, run_id=run_id
+            node, catalog, inputs, is_async, hook_manager, session_id=session_id
         )
         inputs.update(additional_inputs)
 
-        outputs = _call_node_run(node, catalog, inputs, is_async, run_id=run_id)
+        outputs = _call_node_run(
+            node, catalog, inputs, is_async, hook_manager, session_id=session_id
+        )
 
         save_futures = set()
 
         for name, data in outputs.items():
-            hook_manager.hook.before_dataset_saved(  # pylint: disable=no-member
-                dataset_name=name, data=data
-            )
+            hook_manager.hook.before_dataset_saved(dataset_name=name, data=data)
             save_futures.add(pool.submit(catalog.save, name, data))
 
         for future in as_completed(save_futures):
             exception = future.exception()
             if exception:
                 raise exception
-            hook_manager.hook.after_dataset_saved(  # pylint: disable=no-member
+            hook_manager.hook.after_dataset_saved(
                 dataset_name=name, data=data  # pylint: disable=undefined-loop-variable
             )
     return node
